@@ -16,12 +16,12 @@
 import importlib
 
 import async_channel.constants as channel_constants
-import async_channel.channels as channels
 
 import octobot_commons.channels_name as channels_name
 import octobot_commons.enums as commons_enums
 import octobot_commons.constants as commons_constants
 import octobot_commons.errors as commons_errors
+import octobot_commons.databases as commons_databases
 
 import octobot_evaluators.evaluators as evaluator
 import octobot_evaluators.util as evaluators_util
@@ -39,13 +39,9 @@ class ScriptedEvaluator(evaluator.AbstractEvaluator):
         self._has_script_been_called_once = False
 
     def post_init(self, tentacles_setup_config):
-        self.load_config()
         # add config folder to importable files to import the user script
         tentacles_manager_api.import_user_tentacles_config_folder(tentacles_setup_config)
 
-    def load_config(self):
-        self.specific_config = tentacles_manager_api.get_tentacle_config(self.tentacles_setup_config, self.__class__)
-
     async def start(self, bot_id: str) -> bool:
         """
         Default TA start: to be overwritten
@@ -242,17 +238,17 @@ class ScriptedEvaluator(evaluator.AbstractEvaluator):
     def get_script(self):
         return self._script
 
-    async def _user_commands_callback(self, bot_id, subject, action, data) -> None:
-        self.logger.debug(f"Received {action} command.")
-        if action == commons_enums.UserCommands.RELOAD_SCRIPT.value:
-            # live_script = data[AbstractScriptedTradingMode.USER_COMMAND_RELOAD_SCRIPT_IS_LIVE]
-            await self._reload_script()
+    async def user_commands_callback(self, bot_id, subject, action, data) -> None:
+        await super().user_commands_callback(bot_id, subject, action, data)
+        if action in (commons_enums.UserCommands.RELOAD_SCRIPT.value, commons_enums.UserCommands.RELOAD_CONFIG.value):
+            # also reload script on RELOAD_CONFIG
+            await self._reload_script(bot_id)
 
-    async def _reload_script(self):
+    async def _reload_script(self, bot_id):
         importlib.reload(self.__class__.EVALUATOR_SCRIPT_MODULE)
         self.register_script_module(self.__class__.EVALUATOR_SCRIPT_MODULE)
         # reload config
-        self.load_config()
+        await self.reload_config(bot_id)
         if self.last_call:
             # todo cancel and restart live tasks
             # recall script with for are_data_initialized to false to re-write initial data
@@ -277,7 +273,8 @@ class ScriptedEvaluator(evaluator.AbstractEvaluator):
                 trading_api.get_exchange_id_from_matrix_id(self.exchange_name, self.matrix_id)
             )
             bot_id = trading_api.get_bot_id(exchange_manager)
-            return trading_api.get_run_db(bot_id), trading_api.get_symbol_db(bot_id, self.exchange_name, self.symbol)
+            provider = commons_databases.RunDatabasesProvider.instance()
+            return provider.get_run_db(bot_id), provider.get_symbol_db(bot_id, self.exchange_name, self.symbol)
         except ImportError:
             self.logger.error("required OctoBot-trading to get a trading mode writer")
             raise
@@ -301,19 +298,8 @@ class ScriptedEvaluator(evaluator.AbstractEvaluator):
                         new_consumer(self.evaluator_kline_callback, cryptocurrency=cryptocurrency,
                                      symbol=symbol, time_frame=time_frame, priority_level=self.priority_level)
                 )
-            import octobot_services.channel as services_channels
-            try:
-                consumers.append(
-                    await channels.get_chan(services_channels.UserCommandsChannel.get_name()).new_consumer(
-                        self._user_commands_callback,
-                        {"bot_id": bot_id, "subject": self.get_name()}
-                    )
-                )
-            except KeyError:
-                # UserCommandsChannel might not be available
-                pass
         except ImportError:
-            self.logger.warning("Can't connect to trading / services channels")
+            self.logger.warning("Can't connect to trading channels")
         return consumers
 
     def _get_channel_registration(self):
