@@ -43,6 +43,16 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
         self.available_time_frames_cache = {}
         self.available_node_paths_cache = {}
 
+    def init_user_inputs(self, inputs: dict) -> None:
+        """
+        Called right before starting the tentacle, should define all the tentacle's user inputs unless
+        those are defined somewhere else.
+        """
+        self.UI.user_input(constants.STRATEGIES_REQUIRED_TIME_FRAME, common_enums.UserInputTypes.MULTIPLE_OPTIONS,
+                           [common_enums.TimeFrames.ONE_HOUR.value],
+                           inputs, options=[tf.value for tf in common_enums.TimeFrames],
+                           title="Time frame: The time frame to observe in order to spot changes.")
+
     async def start(self, bot_id: str) -> bool:
         """
         Default Strategy start: to be overwritten
@@ -113,9 +123,11 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
         self.available_node_paths_cache = {}
 
     async def stop(self) -> None:
+        await super().stop()
         if self.consumer_instance:
             await evaluator_channels.get_chan(constants.MATRIX_CHANNEL,
                                               self.matrix_id).remove_consumer(self.consumer_instance)
+            self.consumer_instance = None
 
     def get_full_cycle_evaluator_types(self) -> tuple:
         # returns a tuple as it is faster to create than a list
